@@ -170,7 +170,7 @@ main (int argc, char **argv)
 static bool
 test_output (usrp0_tx *utx, bool forever_p)
 {
-  static const int BUFSIZE = 16 * 1024;
+  static const int BUFSIZE = utx->block_size();
   static const int N = BUFSIZE/sizeof (short);
   short 	   buf[N];
   int		   nbytes = 0;
@@ -235,7 +235,7 @@ static bool
 test_input  (usrp0_rx *urx, bool forever_p, FILE *fp)
 {
   int		   fd = -1;
-  static const int BUFSIZE = 16 * 1024;
+  static const int BUFSIZE = urx->block_size();
   static const int N = BUFSIZE/sizeof (short);
   short 	   buf[N];
   int		   nbytes = 0;
