@@ -66,6 +66,14 @@ find_file (const char *filename, int hw_rev)
 {
   char **sp = std_paths;
   static char path[1000];
+  char *s;
+
+  s = getenv("USRP_PATH");
+  if (s) {
+    snprintf (path, sizeof (path), "%s/rev%d/%s", s, hw_rev, filename);
+    if (access (path, R_OK) == 0)
+      return path;
+  }
 
   while (*sp){
     snprintf (path, sizeof (path), "%s/rev%d/%s", *sp, hw_rev, filename);
@@ -220,12 +228,23 @@ usrp_open_interface (struct usb_device *dev, int interface, int altinterface)
     abort ();
   }
 
+#if 0
+  // There's no get get_configuration function, and with some of the newer kernels
+  // setting the configuration, even if to the same value, hoses any other processes
+  // that have it open.  Hence we opt to not set it at all (We've only
+  // got a single configuration anyway).  This may hose the win32 stuff...
+
   if (usb_set_configuration (udh, 1) < 0){
-    fprintf (stderr, "%s: usb_claim_interface: failed conf %d\n", __FUNCTION__,interface);
-    fprintf (stderr, "%s\n", usb_strerror());
-    usb_close (udh);
-    return 0;
+    /*
+     * Ignore this error.  
+     *
+     * Seems that something changed in drivers/usb/core/devio.c:proc_setconfig such that
+     * it returns -EBUSY if _any_ of the interfaces of a device are open.
+     * We've only got a single configuration, so setting it doesn't even seem
+     * like it should be required.
+     */
   }
+#endif
 
   if (usb_claim_interface (udh, interface) < 0){
     fprintf (stderr, "%s:usb_claim_interface: failed interface %d\n", __FUNCTION__,interface);
@@ -954,7 +973,7 @@ usrp_i2c_read (struct usb_dev_handle *udh, int i2c_addr,
 bool
 usrp_spi_write (struct usb_dev_handle *udh,
 		int optional_header, int enables, int format,
-		unsigned char *buf, int len)
+		const void *buf, int len)
 {
   if (len < 0 || len > MAX_EP0_PKTSIZE)
     return false;
@@ -962,14 +981,14 @@ usrp_spi_write (struct usb_dev_handle *udh,
   return write_cmd (udh, VRQ_SPI_WRITE,
 		    optional_header,
 		    ((enables & 0xff) << 8) | (format & 0xff),
-		    buf, len) == len;
+		    (unsigned char *) buf, len) == len;
 }
 
 
 bool
 usrp_spi_read (struct usb_dev_handle *udh,
 	       int optional_header, int enables, int format,
-	       unsigned char *buf, int len)
+	       void *buf, int len)
 {
   if (len < 0 || len > MAX_EP0_PKTSIZE)
     return false;
@@ -977,7 +996,7 @@ usrp_spi_read (struct usb_dev_handle *udh,
   return write_cmd (udh, VRQ_SPI_READ,
 		    optional_header,
 		    ((enables & 0xff) << 8) | (format & 0xff),
-		    buf, len) == len;
+		    (unsigned char *) buf, len) == len;
 }
 
 bool
