@@ -98,18 +98,23 @@ real_rx_mux_value (int mux, int nchan)
 
 usrp_standard_rx::usrp_standard_rx (int which_board,
 				    unsigned int decim_rate,
-				    int nchan, int mux, int mode)
-  : usrp_basic_rx (which_board),
+				    int nchan, int mux, int mode,
+				    int fusb_block_size, int fusb_nblocks)
+  : usrp_basic_rx (which_board, fusb_block_size, fusb_nblocks),
     d_nchan (1), d_sw_mux (0x0), d_hw_mux (0x0)
 {
-  if (!set_decim_rate (decim_rate)){
-    fprintf (stderr, "usrp_standard_rx: set_decim_rate failed\n");
+  if (!set_format(make_format())){
+    fprintf (stderr, "usrp_standard_rx: set_format failed\n");
     throw std::runtime_error ("usrp_standard_rx::ctor");
   }
   if (!set_nchannels (nchan)){
     fprintf (stderr, "usrp_standard_rx: set_nchannels failed\n");
     throw std::runtime_error ("usrp_standard_rx::ctor");
   }
+  if (!set_decim_rate (decim_rate)){
+    fprintf (stderr, "usrp_standard_rx: set_decim_rate failed\n");
+    throw std::runtime_error ("usrp_standard_rx::ctor");
+  }
   if (!set_mux (real_rx_mux_value (mux, nchan))){
     fprintf (stderr, "usrp_standard_rx: set_mux failed\n");
     throw std::runtime_error ("usrp_standard_rx::ctor");
@@ -119,20 +124,21 @@ usrp_standard_rx::usrp_standard_rx (int which_board,
     throw std::runtime_error ("usrp_standard_rx::ctor");
   }
 
-  for (int i = 0; i < MAX_CHAN; i++)
-    set_rx_freq (i, 0);
-
+  for (int i = 0; i < MAX_CHAN; i++){
+    set_rx_freq(i, 0);
+    set_ddc_phase(i, 0);
+  }
 }
 
 usrp_standard_rx::~usrp_standard_rx ()
 {
-  // nop
+  // fprintf(stderr, "\nusrp_standard_rx: dtor\n");
 }
 
 bool
-usrp_standard_rx::initialize ()
+usrp_standard_rx::start ()
 {
-  if (!usrp_basic_rx::initialize ())
+  if (!usrp_basic_rx::start ())
     return false;
 
   // add our code here
@@ -140,20 +146,28 @@ usrp_standard_rx::initialize ()
   return true;
 }
 
+bool
+usrp_standard_rx::stop ()
+{
+  bool ok = usrp_basic_rx::stop ();
+
+  // add our code here
+
+  return ok;
+}
+
 usrp_standard_rx *
 usrp_standard_rx::make (int which_board,
 			unsigned int decim_rate,
-			int nchan, int mux, int mode)
+			int nchan, int mux, int mode,
+			int fusb_block_size, int fusb_nblocks)
 {
   usrp_standard_rx *u = 0;
   
   try {
     u = new usrp_standard_rx (which_board, decim_rate,
-			      nchan, mux, mode);
-    if (!u->initialize ()){
-      fprintf (stderr, "usrp_standard_rx::make failed to initialize\n");
-      throw std::runtime_error ("usrp_standard_rx::make");
-    }
+			      nchan, mux, mode,
+			      fusb_block_size, fusb_nblocks);
     return u;
   }
   catch (...){
@@ -165,23 +179,19 @@ usrp_standard_rx::make (int which_board,
 }
 
 bool
-usrp_standard_rx::set_decim_rate  (unsigned int rate)
+usrp_standard_rx::set_decim_rate(unsigned int rate)
 {
-  if (rate < 1 || rate > 256){
-    fprintf (stderr, "usrp_standard_rx::set_decim_rate: rate must be in [1, 256]\n");
+  if ((rate & 0x1) || rate < 4 || rate > 256){
+    fprintf (stderr, "usrp_standard_rx::set_decim_rate: rate must be EVEN and in [4, 256]\n");
     return false;
   }
 
-  if (rate > 128){
-    fprintf (stderr, "usrp_standard_rx::set_decim_rate: WARNING rates > 128 result in incorrect gain.\n");
-  }
-
   d_decim_rate = rate;
-  set_usb_data_rate ((adc_freq () / rate * nchannels ())
+  set_usb_data_rate ((adc_rate () / rate * nchannels ())
 		     * (2 * sizeof (short)));
 
   bool s = disable_rx ();
-  bool ok = _write_fpga_reg (FR_DECIM_RATE, d_decim_rate - 1);
+  bool ok = _write_fpga_reg (FR_DECIM_RATE, d_decim_rate/2 - 1);
   restore_rx (s);
   return ok;
 }
@@ -299,7 +309,7 @@ usrp_standard_rx::set_rx_freq (int channel, double freq)
     return false;
 
   unsigned int v =
-    compute_freq_control_word_fpga (fpga_master_clock_freq () / 2,
+    compute_freq_control_word_fpga (adc_freq(),
 				    freq, &d_rx_freq[channel],
 				    d_verbose);
 
@@ -330,6 +340,88 @@ usrp_standard_rx::set_fpga_mode (int mode)
   return _write_fpga_reg (FR_MODE, mode);
 }
 
+bool
+usrp_standard_rx::set_ddc_phase(int channel, int phase)
+{
+  if (channel < 0 || channel >= MAX_CHAN)
+    return false;
+
+  return _write_fpga_reg(FR_RX_PHASE_0 + channel, phase);
+}
+
+
+// To avoid quiet failures, check for things that our code cares about.
+
+static bool
+rx_format_is_valid(unsigned int format)
+{
+  int width =  usrp_standard_rx::format_width(format);
+  int want_q = usrp_standard_rx::format_want_q(format);
+
+  if (!(width == 8 || width == 16))	// FIXME add other widths when valid
+    return false;
+
+  if (!want_q)		// FIXME remove check when the rest of the code can handle I only
+    return false;
+
+  return true;
+}
+
+bool
+usrp_standard_rx::set_format(unsigned int format)
+{
+  if (!rx_format_is_valid(format))
+    return false;
+
+  return _write_fpga_reg(FR_RX_FORMAT, format);
+}
+
+unsigned int
+usrp_standard_rx::format() const
+{
+  return d_fpga_shadows[FR_RX_FORMAT];
+}
+
+// ----------------------------------------------------------------
+
+unsigned int 
+usrp_standard_rx::make_format(int width, int shift, bool want_q, bool bypass_halfband)
+{
+  unsigned int format = 
+    (((width << bmFR_RX_FORMAT_WIDTH_SHIFT) & bmFR_RX_FORMAT_WIDTH_MASK)
+     | (shift << bmFR_RX_FORMAT_SHIFT_SHIFT) & bmFR_RX_FORMAT_SHIFT_MASK);
+
+  if (want_q)
+    format |= bmFR_RX_FORMAT_WANT_Q;
+  if (bypass_halfband)
+    format |= bmFR_RX_FORMAT_BYPASS_HB;
+
+  return format;
+}
+
+int
+usrp_standard_rx::format_width(unsigned int format)
+{
+  return (format & bmFR_RX_FORMAT_WIDTH_MASK) >> bmFR_RX_FORMAT_WIDTH_SHIFT;
+}
+
+int
+usrp_standard_rx::format_shift(unsigned int format)
+{
+  return (format & bmFR_RX_FORMAT_SHIFT_MASK) >> bmFR_RX_FORMAT_SHIFT_SHIFT;
+}
+
+bool
+usrp_standard_rx::format_want_q(unsigned int format)
+{
+  return (format & bmFR_RX_FORMAT_WANT_Q) != 0;
+}
+
+bool
+usrp_standard_rx::format_bypass_halfband(unsigned int format)
+{
+  return (format & bmFR_RX_FORMAT_BYPASS_HB) != 0;
+}
 
 //////////////////////////////////////////////////////////////////
 
@@ -367,25 +459,23 @@ real_tx_mux_value (int mux, int nchan)
 
 usrp_standard_tx::usrp_standard_tx (int which_board,
 				    unsigned int interp_rate,
-				    int nchan, int mux)
-  : usrp_basic_tx (which_board),
+				    int nchan, int mux,
+				    int fusb_block_size, int fusb_nblocks)
+  : usrp_basic_tx (which_board, fusb_block_size, fusb_nblocks),
     d_sw_mux (0x8), d_hw_mux (0x81)
 {
   if (!usrp_9862_write_many_all (d_udh, tx_regs_use_nco, sizeof (tx_regs_use_nco))){
     fprintf (stderr, "usrp_standard_tx: failed to init AD9862 TX regs\n");
     throw std::runtime_error ("usrp_standard_tx::ctor");
   }
-
-  if (!set_interp_rate (interp_rate)){
-    fprintf (stderr, "usrp_standard_tx: set_interp_rate failed\n");
-    throw std::runtime_error ("usrp_standard_tx::ctor");
-  }
-
   if (!set_nchannels (nchan)){
     fprintf (stderr, "usrp_standard_tx: set_nchannels failed\n");
     throw std::runtime_error ("usrp_standard_tx::ctor");
   }
-
+  if (!set_interp_rate (interp_rate)){
+    fprintf (stderr, "usrp_standard_tx: set_interp_rate failed\n");
+    throw std::runtime_error ("usrp_standard_tx::ctor");
+  }
   if (!set_mux (real_tx_mux_value (mux, nchan))){
     fprintf (stderr, "usrp_standard_tx: set_mux failed\n");
     throw std::runtime_error ("usrp_standard_tx::ctor");
@@ -401,13 +491,13 @@ usrp_standard_tx::usrp_standard_tx (int which_board,
 
 usrp_standard_tx::~usrp_standard_tx ()
 {
-  // nop
+  // fprintf(stderr, "\nusrp_standard_tx: dtor\n");
 }
 
 bool
-usrp_standard_tx::initialize ()
+usrp_standard_tx::start ()
 {
-  if (!usrp_basic_tx::initialize ())
+  if (!usrp_basic_tx::start ())
     return false;
 
   // add our code here
@@ -415,19 +505,27 @@ usrp_standard_tx::initialize ()
   return true;
 }
 
+bool
+usrp_standard_tx::stop ()
+{
+  bool ok = usrp_basic_tx::stop ();
+
+  // add our code here
+
+  return ok;
+}
+
 usrp_standard_tx *
 usrp_standard_tx::make (int which_board,
 			unsigned int interp_rate,
-			int nchan, int mux)
+			int nchan, int mux,
+			int fusb_block_size, int fusb_nblocks)
 {
   usrp_standard_tx *u = 0;
   
   try {
-    u = new usrp_standard_tx (which_board, interp_rate, nchan, mux);
-    if (!u->initialize ()){
-      fprintf (stderr, "usrp_standard_tx::make failed to initialize\n");
-      throw std::runtime_error ("usrp_standard_tx::make");
-    }
+    u = new usrp_standard_tx (which_board, interp_rate, nchan, mux,
+			      fusb_block_size, fusb_nblocks);
     return u;
   }
   catch (...){
@@ -449,7 +547,7 @@ usrp_standard_tx::set_interp_rate (unsigned int rate)
   }
 
   d_interp_rate = rate;
-  set_usb_data_rate ((dac_freq () / rate * nchannels ())
+  set_usb_data_rate ((dac_rate () / rate * nchannels ())
 		     * (2 * sizeof (short)));
 
   // We're using the interp by 4 feature of the 9862 so that we can
@@ -629,7 +727,6 @@ usrp_standard_tx::set_coarse_modulator (int channel, coarse_mod_t cm)
   }
 
   d_coarse_mod[channel] = cm;
-  // return _write_9862 (channel, REG_TX_MODULATOR, d_tx_modulator_shadow[channel]);
   return true;
 }
 
